class Afsctool < Formula
  desc "Utility for manipulating APFS and ZFS compressed files"
  homepage "https://brkirch.wordpress.com/afsctool/"
  url "https://github.com/RJVB/afsctool/archive/refs/tags/v1.7.3.tar.gz"
  sha256 "5776ff5aaf05c513bead107536d9e98e6037019a0de8a1435cc9da89ea8d49b8"
  license all_of: ["GPL-3.0-only", "BSL-1.0"]
  head "https://github.com/RJVB/afsctool.git"

  depends_on "cmake" => :build
  depends_on "google-sparsehash" => :build
  depends_on "pkg-config" => :build
  depends_on :macos

  resource "lzfse" do
    url "https://github.com/lzfse/lzfse.git",
      revision: "e634ca58b4821d9f3d560cdc6df5dec02ffc93fd"
  end

  def install
    (buildpath/"src/private/lzfse").install resource("lzfse")
    system "cmake", ".", *std_cmake_args
    system "cmake", "--build", "."
    bin.install "afsctool"
    bin.install "zfsctool"
  end

  test do
    path = testpath/"foo"
    sample = "A"*1024*1024
    path.write sample
    original_size = File.stat(path).blocks

    test_options = [[], ["-T", "LZFSE"]]
    test_options.each do |x|
      system "#{bin}/afsctool", "-c", *x, path
      system "#{bin}/afsctool", "-v", path
      raise "Did not compress" unless File.stat(path).blocks.between?(1, 10)

      system "#{bin}/afsctool", "-d", path
      raise "Did not decompress" if File.stat(path).blocks != original_size
      raise "Data corruption" if path.read != sample
    end
  end
end
